Documentation
¶
Overview ¶
Package sink provides functions to create sinks.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Buffered ¶
Buffered creates a new buffered sink.
func Func ¶
Func creates a bar.Sink that sends sends output in the form of Segments.
func New ¶
New creates a new sink and returns a channel that will emit any outputs sent to the sink.
Types ¶
This section is empty.
Source Files
¶
- sink.go
Click to show internal directories.
Click to hide internal directories.